# plotting.py
# AE3M33UI - Artificial Intellignece course, FEE CTU in Prague
#
# Module containing plotting functions.

from matplotlib.pyplot import *

def plot_xy_data(x, y, xlbl='', ylbl=''):
    """Create plot of x,y pairs."""
    figure()
    scatter(x,y)
    xlabel(xlbl, fontsize=16)
    ylabel(ylbl, fontsize=16)
    
def plot_xy_classified_data(x, y, c, xlbl='', ylbl='', colors=None):
    """Create plot of x,y pairs with classes c indicated by different colors."""
    if colors is None:
        colors = ['b','r','g','y','c','m']
    unique_classes = set(c)
    for k in unique_classes:
        scatter(x[c==k],y[c==k], c=colors[k], s=36)
    xlabel(xlbl, fontsize=16)
    ylabel(ylbl, fontsize=16)

def plot_1D_regr_model(model, c='b'):
    """Display predictions of the model in the x-range of an existing figure."""
    # Get the limits of axes in the current graph
    ax = axis()
    # Build a set of points for which we'd like to display the predictions
    Xtst = np.linspace(ax[0], ax[1], 101)
    Xtst = Xtst[:,np.newaxis]
    # Compute the predictions
    raise NotImplementedError
    # <YOUR CODE HERE>
    # Plot them
    plot(Xtst, ytst, lw=3, c=c)
    axis(ax)
    
def plot_2D_class_model(model):
    """Plot the predictions and decision boundary of the model.
    
    Assumes that a plot of data points already exists.
    """
    ax = axis()
    x1 = np.linspace(ax[0], ax[1], num=101)
    x2 = np.linspace(ax[2], ax[3], num=101)
    mx1, mx2 = np.meshgrid(x1, x2)
    sh = mx1.shape
    vx1 = np.reshape(mx1, (-1,1))
    vx2 = np.reshape(mx2, (-1,1))
    vx = np.hstack((vx1,vx2))
    vyhat = model.predict(vx)
    myhat = np.reshape(vyhat, sh)
    contourf(mx1,mx2,myhat,lw=3,cmap=cm.cool, alpha=0.3)

    


